@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-u"""
+"""
 Copyright 2019 Telefónica Investigación y Desarrollo, S.A.U.
 This file is part of Toolium.
 
@@ -25,9 +25,9 @@ from toolium.utils.path_utils import makedirs_safe
 # constants
 STATUS_OK = 200
 STATUS_PORT = '8888'
-DOWNLOADS_PATH = u'downloads'
-MP4_EXTENSION = u'mp4'
-LOG_EXTENSION = u'log'
+DOWNLOADS_PATH = 'downloads'
+MP4_EXTENSION = 'mp4'
+LOG_EXTENSION = 'log'
 
 
 class Selenoid(object):
@@ -38,6 +38,7 @@ class Selenoid(object):
     # capabilities to selenoid
     enableVideo: true
     enableVNC: true
+    enableLog: true
 
     [Server]
     enabled: true            --> MANDATORY
@@ -242,11 +243,11 @@ class Selenoid(object):
     def download_session_log(self, scenario_name, timeout=5):
         """
         download the session log file from remote selenoid,
-        renaming the file to scenario name and removing the video file in the server.
+        renaming the file to scenario name and removing the log file in the server.
              GGR request: http://<username>:<password>@<ggr_host>:<ggr_port>/logs/<ggr_session_id>
         selenoid request: http://<username>:<password>@<ggr_host>:<ggr_port>/logs/<ggr_session_id>.log
         :param scenario_name: scenario name
-        :param timeout: threshold until the video file is downloaded
+        :param timeout: threshold until the log file is downloaded
         """
         # Download logs only in linux nodes with logs enabled
         if (self.driver_wrapper.get_driver_platform().lower() != 'linux' or
